@@ -290,8 +290,8 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'Gray (Gy)', id: 'radgy', fn: decimalSIPrefix('Gy') },
       { name: 'rad', id: 'radrad', fn: decimalSIPrefix('rad') },
       { name: 'Sievert (Sv)', id: 'radsv', fn: decimalSIPrefix('Sv') },
-      { name: 'milliSievert (mSv)', id: 'radmsv', fn: decimalSIPrefix('mSv', -1) },
-      { name: 'microSievert (µSv)', id: 'radusv', fn: decimalSIPrefix('µSv', -2) },
+      { name: 'milliSievert (mSv)', id: 'radmsv', fn: decimalSIPrefix('Sv', -1) },
+      { name: 'microSievert (µSv)', id: 'radusv', fn: decimalSIPrefix('Sv', -2) },
       { name: 'rem', id: 'radrem', fn: decimalSIPrefix('rem') },
       { name: 'Exposure (C/kg)', id: 'radexpckg', fn: decimalSIPrefix('C/kg') },
       { name: 'roentgen (R)', id: 'radr', fn: decimalSIPrefix('R') },
